========
Examples
========

Here we host a large number of example scripts separated into core_examples,
which demonstrate the core features of :code:`bilby`, and gw_examples, which
demonstrate the gravitational-wave-specific features of :code:`bilby`. Finally,
there is also a directory containing various tutorials in the form of
notebooks.

The :code:`basic_tutorial.py` example discussed in arXiv:1811.02042 has been
renamed to `gw_examples/injection_examples/fast_tutorial.py
<https://git.ligo.org/lscsoft/bilby/tree/master/examples/gw_examples/injection_examples/fast_tutorial.py>`_.

